summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--lib/plugins/info/syntax.php2
-rw-r--r--lib/plugins/syntax.php10
2 files changed, 6 insertions, 6 deletions
diff --git a/lib/plugins/info/syntax.php b/lib/plugins/info/syntax.php
index b0cfcba77..0a1b12d81 100644
--- a/lib/plugins/info/syntax.php
+++ b/lib/plugins/info/syntax.php
@@ -72,7 +72,7 @@ class syntax_plugin_info extends DokuWiki_Syntax_Plugin {
/**
* Create output
*/
- function render($mode, &$renderer, $data) {
+ function render($format, &$renderer, $data) {
if($mode == 'xhtml'){
//handle various info stuff
switch ($data[0]){
diff --git a/lib/plugins/syntax.php b/lib/plugins/syntax.php
index f5a2ee90e..b8b496b25 100644
--- a/lib/plugins/syntax.php
+++ b/lib/plugins/syntax.php
@@ -95,23 +95,23 @@ class DokuWiki_Syntax_Plugin extends Doku_Parser_Mode {
* during the object's current life. The only reliable data it receives are its
* parameters.
*
* The function should always check for the given mode and return false
* when a mode isn't supported.
*
* $renderer contains a reference to the renderer object which is
* currently handling the rendering. You need to use it for writing
* the output. How this is done depends on the renderer used (specified
- * by $mode
+ * by $format
*
* The contents of the $data array depends on what the handler() function above
* created
*
- * @param $mode string current Rendermode
+ * @param $format string output format to being Rendered
* @param $renderer ref reference to the current renderer object
* @param $data array data created by handler()
* @return boolean rendered correctly?
*/
- function render($mode, &$renderer, $data) {
+ function render($format, &$renderer, $data) {
trigger_error('render() not implemented in '.get_class($this), E_USER_WARNING);
}
@@ -95,23 +95,23 @@ class DokuWiki_Syntax_Plugin extends Doku_Parser_Mode {
* parameters.
*
- * The function should always check for the given mode and return false
- * when a mode isn't supported.
+ * The function should always check for the given output format and return false
+ * when a format isn't supported.
*
* $renderer contains a reference to the renderer object which is